/*
** Module   : ImageSupport.java
** Abstract : Defines image loading widget-related APIs available via a widget handle instance.
**
** Copyright (c) 2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 EVL 20150128 Created initial version.
** 002 EVL 20150223 Adding CONVERT-3D-COLORS attribute.
*/

package com.goldencode.p2j.ui;

import com.goldencode.p2j.util.*;

/**
 * Provide access to image loading widget-related APIs which can be accessed via handle instance.
 */
public interface ImageSupport
{
   /**
    * Load widget(button or image) image from specified file name.
    * 
    * @param   name
    *          Image file name.
    *          
    * @return  <code>true</code> if operation was successful.
    */
   @LegacyMethod(name = "LOAD-IMAGE")
   public logical loadImage(String name);
   
   /**
    * Load widget(button or image) image from specified file name.
    * 
    * @param   name
    *          Image file name.
    *          
    * @return  <code>true</code> if operation was successful.
    */
   @LegacyMethod(name = "LOAD-IMAGE")
   public logical loadImage(character name);

   /**
    * Gets CONVERT-3D-COLORS attribute.
    * 
    * @return  CONVERT-3D-COLORS current value.
    */
   @LegacyAttribute(name = "CONVERT-3D-COLORS")
   public logical getConvert3D();

   /**
    * Set CONVERT-3D-COLORS attribute.
    * 
    * @param   flag
    *          New value for the option.
    */
   @LegacyAttribute(name = "CONVERT-3D-COLORS", setter = true)
   public void setConvert3D(boolean flag);

   /**
    * Set CONVERT-3D-COLORS attribute.
    * 
    * @param   flag
    *          New value for the option.
    */
   @LegacyAttribute(name = "CONVERT-3D-COLORS", setter = true)
   public void setConvert3D(logical flag);
}
